SpSignalMask class

sp_signal bitmask returned by sp_get_signals (libserialport.h).

Constructors

SpSignalMask()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

cts → const int
Clear To Send.
dcd → const int
Data Carrier Detect (a.k.a. RLSD).
dsr → const int
Data Set Ready.
ri → const int
Ring Indicator.