LibserialportBindings class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spClose SpVoidIntDart
final
spEndBreak SpVoidIntDart
final
spFreePort SpFreePortDart
final
spGetPortByName SpGetPortByNameDart
final
spGetSignals SpGetSignalsDart
final
spNonblockingRead SpReadWriteDart
final
spNonblockingWrite SpReadWriteDart
final
spOpen SpVoidIntFlagDart
final
spSetBaudrate SpVoidIntFlagDart
final
spSetBits SpVoidIntFlagDart
final
spSetDtr SpVoidIntFlagDart
final
spSetFlowControl SpVoidIntFlagDart
final
spSetParity SpVoidIntFlagDart
final
spSetRts SpVoidIntFlagDart
final
spSetStopBits SpVoidIntFlagDart
final
spStartBreak SpVoidIntDart
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited